# NOT RUN {
## In the following example, notice that passing in a vector
## of length 4 returns a design matrix of column dimension 4, where
## each column is comprised of ones vectors with lengths that correspond
## to the inputted sample sizes.
n <- c(1,3,5,8)
gen_Xn(n = n)
# }
Run the code above in your browser using DataLab